#ifndef NT2_INCLUDE_FUNCTIONS_POW2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POW2_HPP_INCLUDED

#include <nt2/exponential/include/functions/pow2.hpp>

#endif
